@@ -71,7 +71,11 @@ static PyObject* build_element(const char type, const char* name, const int leng
     return result;
 }
 
-static PyObject* build_string(int type, const char* string, const char* name) {
+static PyObject* build_string(int type, PyObject* py_string, const char* name) {
+    const char* string = PyString_AsString(py_string);
+    if (!string) {
+        return NULL;
+    }
     int string_length = strlen(string) + 1;
     int data_length = 4 + string_length;
 
@@ -100,21 +104,15 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
      * here we check for type equivalence, not isinstance in some
      * places. */
     if (PyString_CheckExact(value)) {
-        const char* encoded_bytes = PyString_AsString(value);
-        if (!encoded_bytes) {
-            return NULL;
-        }
-        return build_string(0x02, encoded_bytes, name);
+        return build_string(0x02, value, name);
     } else if (PyUnicode_CheckExact(value)) {
         PyObject* encoded = PyUnicode_AsUTF8String(value);
         if (!encoded) {
             return NULL;
         }
-        const char* encoded_bytes = PyString_AsString(encoded);
-        if (!encoded_bytes) {
-            return NULL;
-        }
-        return build_string(0x02, encoded_bytes, name);
+        PyObject* result = build_string(0x02, encoded, name);
+        Py_DECREF(encoded);
+        return result;
     } else if (PyInt_CheckExact(value)) {
         int int_value = (int)PyInt_AsLong(value);
         return build_element(0x10, name, 4, (char*)&int_value);
@@ -132,7 +130,9 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
         if (!object) {
             return NULL;
         }
-        return build_element(0x03, name, PyString_Size(object), PyString_AsString(object));
+        PyObject* result = build_element(0x03, name, PyString_Size(object), PyString_AsString(object));
+        Py_DECREF(object);
+        return result;
     } else if (PyList_CheckExact(value)) {
         PyObject* string = PyString_FromString("");
         int items = PyList_Size(value);
@@ -141,26 +141,35 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
             char* name;
             asprintf(&name, "%d", i);
             if (!name) {
+                Py_DECREF(string);
                 PyErr_NoMemory();
                 return NULL;
             }
-            PyObject* element = _cbson_element_to_bson(self,
-                                                       Py_BuildValue("sO", name,
-                                                                     PyList_GetItem(value, i)));
+            PyObject* args = Py_BuildValue("sO", name, PyList_GetItem(value, i));
             free(name);
+            if (!args) {
+                Py_DECREF(string);
+                return NULL;
+            }
+            PyObject* element = _cbson_element_to_bson(self, args);
+            Py_DECREF(args);
             if (!element) {
+                Py_DECREF(string);
                 return NULL;
             }
             PyString_ConcatAndDel(&string, element);
         }
         PyObject* object = _wrap_py_string_as_object(string);
-        return build_element(0x04, name, PyString_Size(object), PyString_AsString(object));
+        PyObject* result = build_element(0x04, name, PyString_Size(object), PyString_AsString(object));
+        Py_DECREF(object);
+        return result;
     } else if (PyObject_IsInstance(value, Binary)) {
         PyObject* subtype_object = PyObject_CallMethod(value, "subtype", NULL);
         if (!subtype_object) {
             return NULL;
         }
         long subtype = PyInt_AsLong(subtype_object);
+        Py_DECREF(subtype_object);
         PyObject* string;
         int length = PyString_Size(value);
         if (subtype == 2) {
@@ -169,28 +178,29 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
             length += 4;
         } else {
             string = value;
+            Py_INCREF(string);
         }
         char* data = malloc(5 + length);
         if (!data) {
+            Py_DECREF(string);
             PyErr_NoMemory();
             return NULL;
         }
         const char* string_data = PyString_AsString(string);
         if (!string_data) {
+            Py_DECREF(string);
+            free(data);
             return NULL;
         }
         memcpy(data, &length, 4);
         data[4] = (char)subtype;
         memcpy(data + 5, string_data, length);
+        Py_DECREF(string);
         PyObject* result = build_element(0x05, name, length + 5, data);
         free(data);
         return result;
     } else if (PyObject_IsInstance(value, Code)) {
-        const char* encoded_bytes = PyString_AsString(value);
-        if (!encoded_bytes) {
-            return NULL;
-        }
-        return build_string(0x0D, encoded_bytes, name);
+        return build_string(0x0D, value, name);
     } else if (PyDateTime_CheckExact(value)) {
         time_t rawtime;
         time(&rawtime);
@@ -206,11 +216,17 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
         time_since_epoch += PyDateTime_DATE_GET_MICROSECOND(value) / 1000;
         return build_element(0x09, name, 8, (char*)&time_since_epoch);
     } else if (PyObject_IsInstance(value, ObjectId)) {
-        const char* pre_shuffle = PyString_AsString(PyObject_Str(value));
+        PyObject* pystring = PyObject_Str(value);
+        if (!pystring) {
+            return NULL;
+        }
+        const char* pre_shuffle = PyString_AsString(pystring);
         if (!pre_shuffle) {
+            Py_DECREF(pystring);
             return NULL;
         }
         char* shuffled = shuffle_oid(pre_shuffle);
+        Py_DECREF(pystring);
         PyObject* result = build_element(0x07, name, 12, shuffled);
         free(shuffled);
         return result;
@@ -220,32 +236,46 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
             return NULL;
         }
         PyObject* encoded_collection = PyUnicode_AsUTF8String(collection_object);
+        Py_DECREF(collection_object);
         if (!encoded_collection) {
             return NULL;
         }
         const char* collection = PyString_AsString(encoded_collection);
         if (!collection) {
+            Py_DECREF(encoded_collection);
             return NULL;
         }
         PyObject* id_object = PyObject_CallMethod(value, "id", NULL);
         if (!id_object) {
+            Py_DECREF(encoded_collection);
             return NULL;
         }
-        const char* id = PyString_AsString(PyObject_Str(id_object));
+        PyObject* id_str = PyObject_Str(id_object);
+        Py_DECREF(id_object);
+        if (!id_str) {
+            Py_DECREF(encoded_collection);
+            return NULL;
+        }
+        const char* id = PyString_AsString(id_str);
         if (!id) {
+            Py_DECREF(encoded_collection);
+            Py_DECREF(id_str);
             return NULL;
         }
         char* shuffled = shuffle_oid(id);
+        Py_DECREF(id_str);
 
         int collection_length = strlen(collection) + 1;
         char* data = (char*)malloc(4 + collection_length + 12);
         if (!data) {
+            Py_DECREF(encoded_collection);
             free(shuffled);
             PyErr_NoMemory();
             return NULL;
         }
         memcpy(data, &collection_length, 4);
         memcpy(data + 4, collection, collection_length);
+        Py_DECREF(encoded_collection);
         memcpy(data + 4 + collection_length, shuffled, 12);
         free(shuffled);
 
@@ -254,8 +284,17 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
         return result;
     } else if (PyObject_HasAttrString(value, "pattern") &&
                PyObject_HasAttrString(value, "flags")) { // TODO just a proxy for checking if it is a compiled re
-        const char* pattern =  PyString_AsString(PyObject_GetAttrString(value, "pattern"));
-        long int_flags = PyInt_AsLong(PyObject_GetAttrString(value, "flags"));
+        PyObject* py_flags = PyObject_GetAttrString(value, "flags");
+        if (!py_flags) {
+            return NULL;
+        }
+        long int_flags = PyInt_AsLong(py_flags);
+        Py_DECREF(py_flags);
+        PyObject* py_pattern = PyObject_GetAttrString(value, "pattern");
+        if (!py_pattern) {
+            return NULL;
+        }
+        const char* pattern =  PyString_AsString(py_pattern);
         char flags[10];
         flags[0] = 0;
         // TODO don't hardcode these
@@ -281,10 +320,12 @@ static PyObject* _cbson_element_to_bson(PyObject* self, PyObject* args) {
         int flags_length = strlen(flags) + 1;
         char* data = malloc(pattern_length + flags_length);
         if (!data) {
+            Py_DECREF(py_pattern);
             PyErr_NoMemory();
             return NULL;
         }
         memcpy(data, pattern, pattern_length);
+        Py_DECREF(py_pattern);
         memcpy(data + pattern_length, flags, flags_length);
         PyObject* result = build_element(0x0B, name, pattern_length + flags_length, data);
         free(data);
@@ -298,6 +339,7 @@ static PyObject* _wrap_py_string_as_object(PyObject* string) {
     int length = PyString_Size(string) + 5;
     char* data = (char*)malloc(length);
     if (!data) {
+        Py_DECREF(string);
         PyErr_NoMemory();
         return NULL;
     }
@@ -305,6 +347,7 @@ static PyObject* _wrap_py_string_as_object(PyObject* string) {
     memcpy(data, &length, 4);
     memcpy(data + 4, elements, length - 5);
     data[length - 1] = 0x00;
+    Py_DECREF(string);
 
     PyObject* result = Py_BuildValue("s#", data, length);
     free(data);
@@ -321,12 +364,16 @@ static PyObject* _cbson_dict_to_bson(PyObject* self, PyObject* dict) {
             return NULL;
         }
         while (PyDict_Next(dict, &pos, &key, &value)) {
-            PyObject* element = _cbson_element_to_bson(self,
-                                                       Py_BuildValue("OO", key, value));
+            PyObject* args = Py_BuildValue("OO", key, value);
+            if (!args) {
+                return NULL;
+            }
+            PyObject* element = _cbson_element_to_bson(self, args);
             if (!element) {
                 return NULL;
             }
             PyString_ConcatAndDel(&string, element);
+            Py_DECREF(args);
         }
         return _wrap_py_string_as_object(string);
     } else if (PyObject_IsInstance(dict, SON)) {
@@ -336,6 +383,7 @@ static PyObject* _cbson_dict_to_bson(PyObject* self, PyObject* dict) {
         }
         PyObject* keys = PyObject_CallMethod(dict, "keys", NULL);
         if (!keys) {
+            Py_DECREF(string);
             return NULL;
         }
         int items = PyList_Size(keys);
@@ -343,16 +391,26 @@ static PyObject* _cbson_dict_to_bson(PyObject* self, PyObject* dict) {
         for(i = 0; i < items; i++) {
             PyObject* name = PyList_GetItem(keys, i);
             if (!name) {
+                Py_DECREF(string);
+                Py_DECREF(keys);
                 return NULL;
             }
-            PyObject* element = _cbson_element_to_bson(self,
-                                                       Py_BuildValue("OO", name,
-                                                                     PyDict_GetItem(dict, name)));
+            PyObject* args = Py_BuildValue("OO", name, PyDict_GetItem(dict, name));
+            if (!args) {
+                Py_DECREF(string);
+                Py_DECREF(keys);
+                return NULL;
+            }
+            PyObject* element = _cbson_element_to_bson(self, args);
+            Py_DECREF(args);
             if (!element) {
+                Py_DECREF(string);
+                Py_DECREF(keys);
                 return NULL;
             }
             PyString_ConcatAndDel(&string, element);
         }
+        Py_DECREF(keys);
         return _wrap_py_string_as_object(string);
     }
     PyErr_SetString(PyExc_TypeError, "argument to from_dict must be a mapping type");
@@ -410,6 +468,7 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                     return NULL;
                 }
                 value = _elements_to_dict(array_elements);
+                Py_DECREF(array_elements);
                 if (!value) {
                     return NULL;
                 }
@@ -425,6 +484,7 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                     return NULL;
                 }
                 PyObject* array_dict = _elements_to_dict(array_elements);
+                Py_DECREF(array_elements);
                 if (!array_dict) {
                     return NULL;
                 }
@@ -437,23 +497,26 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                     char* key;
                     asprintf(&key, "%d", i);
                     if (!key) {
+                        Py_DECREF(array_dict);
                         PyErr_NoMemory();
                         return NULL;
                     }
                     PyObject* to_append = PyDict_GetItemString(array_dict, key);
                     free(key);
                     if (!to_append) {
+                        Py_DECREF(array_dict);
                         return NULL;
                     }
                     PyList_Append(value, to_append);
                 }
+                Py_DECREF(array_dict);
                 break;
             }
         case 5:
             {
                 int length;
                 memcpy(&length, string + position, 4);
-                int subtype = (int)string[position + 4];
+                int subtype = (unsigned char)string[position + 4];
                 PyObject* data;
                 if (subtype == 2) {
                     data = PyString_FromStringAndSize(string + position + 9, length - 4);
@@ -463,7 +526,14 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                 if (!data) {
                     return NULL;
                 }
-                value = PyObject_CallFunctionObjArgs(Binary, data, PyInt_FromLong(subtype), NULL);
+                PyObject* st = PyInt_FromLong(subtype);
+                if (!st) {
+                    Py_DECREF(data);
+                    return NULL;
+                }
+                value = PyObject_CallFunctionObjArgs(Binary, data, st, NULL);
+                Py_DECREF(st);
+                Py_DECREF(data);
                 if (!value) {
                     return NULL;
                 }
@@ -474,6 +544,7 @@ static PyObject* _elements_to_dict(PyObject* elements) {
         case 10:
             {
                 value = Py_None;
+                Py_INCREF(value);
                 break;
             }
         case 7:
@@ -490,6 +561,7 @@ static PyObject* _elements_to_dict(PyObject* elements) {
         case 8:
             {
                 value = string[position++] ? Py_True : Py_False;
+                Py_INCREF(value);
                 break;
             }
         case 9:
@@ -538,6 +610,7 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                 }
                 position += flags_length + 1;
                 value = PyObject_CallFunction(RECompile, "Oi", pattern, flags);
+                Py_DECREF(pattern);
                 break;
             }
         case 12:
@@ -553,10 +626,13 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                 PyObject* id = PyObject_CallFunction(ObjectId, "s#", shuffled, 12);
                 free(shuffled);
                 if (!id) {
+                    Py_DECREF(collection);
                     return NULL;
                 }
                 position += 12;
                 value = PyObject_CallFunctionObjArgs(DBRef, collection, id, NULL);
+                Py_DECREF(collection);
+                Py_DECREF(id);
                 break;
             }
         case 16:
@@ -571,11 +647,12 @@ static PyObject* _elements_to_dict(PyObject* elements) {
                 break;
             }
         default:
-            printf("type: %d\n", type);
             PyErr_SetString(CBSONError, "no c decoder for this type yet");
             return NULL;
         }
         PyDict_SetItem(dict, name, value);
+        Py_DECREF(name);
+        Py_DECREF(value);
     }
     return dict;
 }
@@ -597,14 +674,19 @@ static PyObject* _cbson_bson_to_dict(PyObject* self, PyObject* bson) {
         return NULL;
     }
     PyObject* dict = _elements_to_dict(elements);
+    Py_DECREF(elements);
     if (!dict) {
         return NULL;
     }
     PyObject* remainder = PySequence_GetSlice(bson, size, PyString_Size(bson));
     if (!remainder) {
+        Py_DECREF(dict);
         return NULL;
     }
-    return Py_BuildValue("OO", dict, remainder);
+    PyObject* result = Py_BuildValue("OO", dict, remainder);
+    Py_DECREF(dict);
+    Py_DECREF(remainder);
+    return result;
 }
 
 static PyMethodDef _CBSONMethods[] = {
