@@ -16,6 +16,7 @@
 
 import types
 
+import pymongo
 import bson
 from objectid import ObjectId
 from cursor import Cursor
@@ -67,7 +68,7 @@ class Collection(object):
         command = SON({"create": self.__collection_name})
         command.update(options)
 
-        response = self.__database._command(command)
+        self.__database._command(command)
 
     def __getattr__(self, name):
         """Get a sub-collection of this collection by name.
@@ -255,7 +256,7 @@ class Collection(object):
             return result
         return None
 
-    def find(self, spec=None, fields=[], skip=0, limit=0):
+    def find(self, spec=None, fields=None, skip=0, limit=0):
         """Query the database.
 
         Raises TypeError if any of the arguments are of improper type. Returns
@@ -275,18 +276,20 @@ class Collection(object):
             spec = SON()
         if not isinstance(spec, types.DictType):
             raise TypeError("spec must be an instance of dict")
-        if not isinstance(fields, types.ListType):
+        if not isinstance(fields, (types.ListType, types.NoneType)):
             raise TypeError("fields must be an instance of list")
         if not isinstance(skip, types.IntType):
             raise TypeError("skip must be an instance of int")
         if not isinstance(limit, types.IntType):
             raise TypeError("limit must be an instance of int")
 
-        return_fields = len(fields) and SON() or None
-        for field in fields:
-            if not isinstance(field, types.StringTypes):
-                raise TypeError("fields must be a list of key names as (string, unicode)")
-            return_fields[field] = 1
+        return_fields = None
+        if fields is not None:
+            return_fields = {}
+            for field in fields:
+                if not isinstance(field, types.StringTypes):
+                    raise TypeError("fields must be a list of key names as (string, unicode)")
+                return_fields[field] = 1
 
         return Cursor(self, spec, return_fields, skip, limit)
 
@@ -312,28 +315,11 @@ class Collection(object):
           - `direction` (optional): must be included if key_or_list is a single
             key, otherwise must be None
         """
-        if direction:
-            keys = [(key_or_list, direction)]
-        else:
-            keys = key_or_list
-
-        if not isinstance(keys, types.ListType):
-            raise TypeError("if no direction is specified, key_or_list must be an instance of list")
-        if not len(keys):
-            raise ValueError("key_or_list must not be the empty list")
-
         to_save = SON()
+        keys = pymongo._index_list(key_or_list, direction)
         to_save["name"] = self._gen_index_name(keys)
         to_save["ns"] = self.full_name()
-
-        key_object = SON()
-        for (key, value) in keys:
-            if not isinstance(key, types.StringTypes):
-                raise TypeError("first item in each key pair must be a string")
-            if not isinstance(value, types.IntType):
-                raise TypeError("second item in each key pair must be ASCENDING or DESCENDING")
-            key_object[key] = value
-        to_save["key"] = key_object
+        to_save["key"] = pymongo._index_document(keys)
 
         self.__database.system.indexes.save(to_save, False)
         return to_save["name"]
