@@ -101,7 +101,7 @@ class Connection(object):
         Return a tuple (host, port). Return True if this connection is
         the master.
         """
-        result = self.admin._command({"ismaster": 1})
+        result = self["admin"]._command({"ismaster": 1})
 
         if result["ismaster"] == 1:
             return True
@@ -140,7 +140,7 @@ class Connection(object):
                 self.__socket.settimeout(_TIMEOUT)
                 self.__socket.connect((host, port))
                 master = self._master()
-                if master == True:
+                if master is True:
                     _logger.debug("success")
                     self.__host = host
                     self.__port = port
@@ -195,15 +195,10 @@ class Connection(object):
         to_send += data
 
         total_sent = 0
-        retry = True
         while total_sent < len(to_send):
             sent = self.__socket.send(to_send[total_sent:])
             if sent == 0:
-                if retry:
-                    retry = False
-                    self.__connect()
-                else:
-                    raise ConnectionFailure("connection closed")
+                raise ConnectionFailure("connection closed")
             total_sent += sent
 
         return self.__id - 1
@@ -222,15 +217,10 @@ class Connection(object):
         """
         def receive(length):
             message = ""
-            retry = True
             while len(message) < length:
                 chunk = self.__socket.recv(length - len(message))
                 if chunk == "":
-                    if retry:
-                        retry = False
-                        self.__connect()
-                    else:
-                        raise ConnectionFailure("connection closed")
+                    raise ConnectionFailure("connection closed")
                 message += chunk
             return message
 
@@ -310,7 +300,7 @@ class Connection(object):
     def __database_info(self):
         """Get a dictionary of (database_name: size_on_disk).
         """
-        result = self.admin._command({"listDatabases": 1})
+        result = self["admin"]._command({"listDatabases": 1})
         info = result["databases"]
         return dict([(db["name"], db["sizeOnDisk"]) for db in info])
 
